package vc.thinker.thirdpartyproxy.protocolimpls.centralAir;

import com.alibaba.fastjson.JSONObject;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.ObjectUtils;
import vc.thinker.absctacts.protocolproxy.enums.IProtocolType;
import vc.thinker.absctacts.protocolproxy.protocol.AbstractThirdPartyProtocolSyncMeterInfo;
import vc.thinker.config.device.DeviceInfoConfig;
import vc.thinker.forwardthinker.ThinkerProdProtocolClient;
import vc.thinker.forwardthinker.dto.ThinkerReportDTO;
import vc.thinker.thirdpartyproxy.ProtocolType;
import vc.thinker.thirdpartyproxy.protocolimpls.centralAir.dto.DataReportInfoDTO;
import vc.thinker.thirdpartyproxy.protocolimpls.centralAir.dto.DataReportParamDTO;

/**
 * 中央空调代理上报网关协议
 *
 * @author HeTongHao
 * @since 2021/7/9 17:13
 */
@Slf4j
@Component
@RequiredArgsConstructor
public class CentralAirProtocol extends AbstractThirdPartyProtocolSyncMeterInfo implements TerminalReportData {

    @Autowired
    private DeviceInfoConfig deviceInfoConfig;

    @Autowired
    protected ThinkerProdProtocolClient thinkerProdProtocolClient;

    @Override
    public IProtocolType protocolType() {
        return ProtocolType.central_air_conditioning;
    }

    @Override
    public String lastDeviceId(DataReportInfoDTO dataReportInfoDTO) {
        return deviceInfoConfig.getCode();
    }

//    @Override
//    public void dataReport(DataReportInfoDTO dataReportInfoDTO) {
//        LocalDateTime time = LocalDateTime.ofEpochSecond(dataReportInfoDTO.getTimestamp()/1000L,0, ZoneOffset.of("+8"));
//        String deviceId = lastDeviceId(dataReportInfoDTO);
//        DataReportParamDTO paramDTO = dataReportInfoDTO.getData();
//        if (ObjectUtils.isEmpty(paramDTO)){
//            return;
//        }
//        MeterReportEntity.MeterReportEntityBuilder builder = MeterReportEntity.builder(deviceId, time);
//        if (!ObjectUtils.isEmpty(paramDTO.getElectricity())){
//            builder.putValue(CentralAirMeterAttrDefine.electricity, dataReportInfoDTO.getData().getElectricity());
//        }
//        if (!ObjectUtils.isEmpty(paramDTO.getColdCapacity())) {
//            builder.putValue(CentralAirMeterAttrDefine.coldCapacity, dataReportInfoDTO.getData().getColdCapacity());
//        }
//        if (!ObjectUtils.isEmpty(paramDTO.getSystemCop())) {
//            builder.putValue(CentralAirMeterAttrDefine.systemCop, dataReportInfoDTO.getData().getSystemCop());
//        }
//        if (!ObjectUtils.isEmpty(paramDTO.getSupplyWaterTemp())) {
//            builder.putValue(CentralAirMeterAttrDefine.supplyWaterTemp, dataReportInfoDTO.getData().getSupplyWaterTemp());
//        }
//        if (!ObjectUtils.isEmpty(paramDTO.getReturnWaterTemp())) {
//            builder.putValue(CentralAirMeterAttrDefine.returnWaterTemp, dataReportInfoDTO.getData().getReturnWaterTemp());
//        }
//        MeterReportEntity meterReport = builder.build();
//        System.out.println("____"+ JSONObject.toJSONString(meterReport));
//        report(meterReport);
//    }


    @Override
    public void dataReport(DataReportInfoDTO dataReportInfoDTO) {
        ThinkerReportDTO dto = new ThinkerReportDTO();
        dto.setDeviceCode(deviceInfoConfig.getCode());
        dto.setTimestamp(dataReportInfoDTO.getTimestamp());
        JSONObject dataMap = new JSONObject();
        DataReportParamDTO paramDTO = dataReportInfoDTO.getData();
        if (!ObjectUtils.isEmpty(paramDTO.getElectricity())){
            dataMap.put(CentralAirMeterAttrDefine.electricity.getCode(), dataReportInfoDTO.getData().getElectricity());
        }
        if (!ObjectUtils.isEmpty(paramDTO.getColdCapacity())) {
            dataMap.put(CentralAirMeterAttrDefine.coldCapacity.getCode(), dataReportInfoDTO.getData().getColdCapacity());
        }
        if (!ObjectUtils.isEmpty(paramDTO.getSystemCop())) {
            dataMap.put(CentralAirMeterAttrDefine.systemCop.getCode(), dataReportInfoDTO.getData().getSystemCop());
        }
        if (!ObjectUtils.isEmpty(paramDTO.getSupplyWaterTemp())) {
            dataMap.put(CentralAirMeterAttrDefine.supplyWaterTemp.getCode(), dataReportInfoDTO.getData().getSupplyWaterTemp());
        }
        if (!ObjectUtils.isEmpty(paramDTO.getReturnWaterTemp())) {
            dataMap.put(CentralAirMeterAttrDefine.returnWaterTemp.getCode(), dataReportInfoDTO.getData().getReturnWaterTemp());
        }
        dto.setDatas(dataMap);
        thinkerProdProtocolClient.report(protocolType().getCode(),dto);
    }
}
